% Author: Alberto Santini <a.santini@unibo.it>

\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{cmrtechreport}[CMR Technical Report LaTeX Template]

% Our class is cmrd on the Standard LaTeX class "report"
\LoadClassWithOptions{report}

% We need titlesec for custom secion titles
\RequirePackage[medium]{titlesec}

% We need background to set the front page's background
\RequirePackage[all]{background}

% We need esopic to be able to place the background at the right place
\RequirePackage{eso-pic}

% We need parskip as we want to have 0-indent in paragraphs by default
\RequirePackage{parskip}

% We need tikz for some graphics
\RequirePackage{tikz}

% We use geometry to specify our pages' layout
\usepackage[top=3cm,bottom=3cm,left=3cm,right=3cm]{geometry}

% Use lmodern for all-caps fonts
\usepackage{lmodern}

% Use hyperref and color for links
\usepackage{color}
\usepackage[bookmarks=false,colorlinks=false]{hyperref}

% Each document may optionally specify the following fields for title page images:
% - bottom background image \botbkgimg
% - title image \titleimg
% - bottom banner bottom right logo \botlogoimg

\newcommand{\@botbkgimg}{cmrtechreport_figures/default_bottom_bkg.png}
\newcommand{\botbkgimg}[1]{%
  \renewcommand{\@botbkgimg}{#1}
}

\newcommand{\@titleimg}{cmrtechreport_figures/default_title.png}
\newcommand{\titleimg}[1]{%
  \renewcommand{\@titleimg}{#1}
}

\newcommand{\@botlogoimg}{cmrtechreport_figures/default_bottom_logo.png}
\newcommand{\botlogoimg}[1]{%
  \renewcommand{\@botlogoimg}{#1}
}

\ProvidesFile{\@botbkgimg}[Bottom Background Image]
\ProvidesFile{\@titleimg}[Title Image]
\ProvidesFile{\@botlogoimg}[Bottom Logo Image]

% Check that all provided files actually exist:
\IfFileExists{\@botbkgimg}{}{\ClassError{cmrtechreport}{The bottom background image is missing!}}
\IfFileExists{\@titleimg}{}{\ClassError{cmrtechreport}{The title page image is missing!}}
\IfFileExists{\@botlogoimg}{}{\ClassError{cmrtechreport}{The bottom logo image is missing!}}

% Each document must specify the following required fields:
%
% Document fields:
% - title (latex)
% - author (latex)
% - date (latex)
% - report id \reportid
% - version \version
%
% Organization:
% - first-level \orghierarchyfirst
% - second-level \orghierarchysecond

\newcommand{\@reportid}{00000000-0000-0000-0000-000000000001} 
\newcommand{\reportid}[1]{%
  \renewcommand{\@reportid}{#1}
}

\newcommand{\@version}{Version X.Y.Z}
\newcommand{\version}[1]{%
  \renewcommand{\@version}{#1}
}

\newcommand{\@orgurl}{https://golly.life}
\newcommand{\orgurl}[1]{%
  \renewcommand{\@orgurl}{#1}
}

% First-level org hierarchy: department, bureau, etc.
\newcommand{\@orghierarchyfirst}{Adjustment Bureau}
\newcommand{\orghierarchyfirst}[1]{%
  \renewcommand{\@orghierarchyfirst}{#1}
}

% Second-level org hierarchy: division, branch, institute, etc.
\newcommand{\@orghierarchysecond}{Office of Unassigned Tasks}
\newcommand{\orghierarchysecond}[1]{%
  \renewcommand{\@orghierarchysecond}{#1}
}

% Clear the background
\SetBgContents{}

% Format chapter and section headers
\titleformat{\chapter}{\scshape\Huge}{\thechapter}{0.5em}{}
\titleformat{\section}{\scshape\Large\vspace{-0.3em}}{\thesection}{0.3em}{}[\titlerule]

% Things to do at the beginning of the document
\AtBeginDocument{%
  % ------------------------------------------------------------------------------------------------
  % 1. Set the command to draw the line drawing design for page headers
  % ------------------------------------------------------------------------------------------------
  \definecolor{orblue}{rgb}{0.173,0.243,0.314}
  \newcommand{\HeaderDrawing}{%
    \begin{tikzpicture}[overlay, remember picture, yshift=-6cm]
      %\draw[thick, orblue] (0,0) -- (2,0) -- (1.479,2.954) -- (2.464,3.128) -- (3.015,0) -- (4,0) -- (4,5) -- (5,5) -- (5,0) -- (60,0);
      \draw[thick, orblue] (0,0) -- (2,0) -- (2,2) -- (4,2) -- (4,4) -- (5,4) -- (5,0) -- (60,0);
      \node[orblue] at (18,1.5) {\Huge Report ID: \@reportid};
    \end{tikzpicture}
  }
  
  % ------------------------------------------------------------------------------------------------
  % 2. Set the command for the background picture
  % ------------------------------------------------------------------------------------------------
  \newcommand{\BackgroundPic}{%
    \put(0,0){%
      \parbox[b][\paperheight]{\paperwidth}{%
        \vfill\includegraphics[width=\paperwidth,height=\paperheight,keepaspectratio]{\@botbkgimg}
      }
    }
  }
  
  % ------------------------------------------------------------------------------------------------
  % 3. Make the title page
  % ------------------------------------------------------------------------------------------------
  \newgeometry{top=2.4cm,bottom=2.4cm,left=2.4cm,right=2.4cm}
  \makeatletter

  \begin{titlepage}
    \AddToShipoutPicture*{\BackgroundPic}
  
    \begin{center}
        \vspace*{1em}
        \includegraphics[height=12em,keepaspectratio]{\@titleimg}\\
        \vspace{4em}
        {\sffamily\Huge \@title}\\[2em]
        {\sffamily \@author}\\[4em]
        {\sffamily\Large \@orghierarchysecond}\\[2em]
        {\sffamily Report ID: \@reportid}\\
        {\sffamily \@date\,|\,\@version }
        \vfill
        \begin{tikzpicture}[overlay, remember picture]
          \fill[black,opacity=0.5] (-12,-0.4) rectangle (12,-2.4);
          \node[color=white] at (-5,-1.4) {\sffamily {\Huge \@orghierarchyfirst}~~~Technical Reports};
          \node at (5.75,-1.4) {\includegraphics[height=2.2em,keepaspectratio]{\@botlogoimg}};
          \node[color=white] at (8,-1.5) {\sffamily \@orgurl};
        \end{tikzpicture}
    \end{center}
  \end{titlepage}

  \makeatother
  \restoregeometry
  
  % ------------------------------------------------------------------------------------------------
  % 4. Set the page header
  % ------------------------------------------------------------------------------------------------
  \SetBgContents{\HeaderDrawing}
  \SetBgPosition{current page.north west}
  \SetBgScale{0.4}
  \SetBgAngle{0.0}
  
  % ------------------------------------------------------------------------------------------------
  % 5. Print the table of contents
  % ------------------------------------------------------------------------------------------------
  %\tableofcontents
}
